package de.drmaxnix.mfcbalance

import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.Home
import androidx.compose.material.icons.filled.Settings
import androidx.compose.material3.Icon
import androidx.compose.material3.NavigationBar
import androidx.compose.material3.NavigationBarItem
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.MutableIntState
import androidx.compose.runtime.mutableIntStateOf
import androidx.compose.runtime.saveable.rememberSaveable
import androidx.compose.ui.graphics.vector.ImageVector
import androidx.compose.ui.tooling.preview.Preview
import androidx.navigation.NavController
import androidx.navigation.compose.rememberNavController
import de.drmaxnix.mfcbalance.ui.theme.MFCBalanceTheme

@Composable
fun BottomNavigationBar(
    navController: NavController,
    selectedNavigationIndex: MutableIntState,
){
    val navigationItems = listOf(
        NavigationItem(
            title = "Home",
            icon = Icons.Default.Home,
            route = Screen.Home.route,
        ),
        NavigationItem(
            title = "Settings",
            icon = Icons.Default.Settings,
            route = Screen.Settings.route,
        ),
    )

    NavigationBar {
        navigationItems.forEachIndexed { index, item ->
            NavigationBarItem(
                selected = selectedNavigationIndex.intValue == index,
                onClick = {
                    selectedNavigationIndex.intValue = index
                    navController.navigate(item.route)
                },
                icon = {
                    Icon(imageVector = item.icon, contentDescription = item.title)
                },
                label = {
                    Text(text = item.title)
                }
            )
        }
    }
}


@Preview
@Composable
fun BottomNavigationBarPreview() {
    MFCBalanceTheme {
        BottomNavigationBar(
            navController = rememberNavController(),
            selectedNavigationIndex = rememberSaveable { mutableIntStateOf(0) }
        )
    }
}

@Preview
@Composable
fun BottomNavigationBarPreviewDark() {
    MFCBalanceTheme(darkTheme = true){
        BottomNavigationBar(
            navController = rememberNavController(),
            selectedNavigationIndex = rememberSaveable { mutableIntStateOf(0) }
        )
    }
}

data class NavigationItem(
    val title: String,
    val icon: ImageVector,
    val route: String,
)