package de.drmaxnix.mfcbalance.screen

import android.content.Intent
import android.provider.Settings
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.rememberScrollState
import androidx.compose.foundation.verticalScroll
import androidx.compose.material3.Button
import androidx.compose.material3.Card
import androidx.compose.material3.CardDefaults
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.alpha
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.platform.LocalInspectionMode
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.preference.PreferenceManager
import de.drmaxnix.mfcbalance.ui.theme.MFCBalanceTheme

@Composable
fun Home(
    instructions: String,
    showNfcSettingsButton: Boolean,
    balance: String,
    ageString: String,
    debugText: String
){
    Column(
        modifier = Modifier.verticalScroll(rememberScrollState())
    ){
        Column(
            verticalArrangement = Arrangement.spacedBy(16.dp),
            modifier = Modifier.padding(16.dp)
        ){
            BalanceCard(
                instructions = instructions,
                showNfcSettingsButton = showNfcSettingsButton,
                balance = balance,
                ageString = ageString,
                debugText = debugText
            )
        }
    }
}

@Composable
fun BalanceCard(
    instructions: String,
    showNfcSettingsButton: Boolean,
    balance: String,
    ageString: String,
    debugText: String
){
    Card(
        colors = CardDefaults.cardColors(
            containerColor = MaterialTheme.colorScheme.surfaceContainer,
        ),
        modifier = Modifier.fillMaxWidth()
    ){
        Card(
            colors = CardDefaults.cardColors(
                containerColor = MaterialTheme.colorScheme.primaryContainer,
            ),
            modifier = Modifier.fillMaxWidth()
        ){
            Box(
                contentAlignment = Alignment.Center
            ){
                Column(
                    verticalArrangement = Arrangement.spacedBy(16.dp),
                    modifier = Modifier.padding(16.dp)
                ){
                    Text(
                        text = balance.ifEmpty { "---" },
                        fontSize = 42.sp,
                        fontWeight = FontWeight.Bold,
                        textAlign = TextAlign.Center,
                        modifier = Modifier
                            .fillMaxWidth()
                            .alpha(if(balance.isEmpty()) 0.0f else 1.0f)
                            .padding(top = 16.dp)
                    )

                    Text(
                        text = ageString,
                        textAlign = TextAlign.End,
                        color = MaterialTheme.colorScheme.primary,
                        modifier = Modifier
                            .fillMaxWidth()
                            .alpha(if(balance.isEmpty()) 0.0f else 1.0f)
                    )
                }

                Column(
                    horizontalAlignment = Alignment.CenterHorizontally,
                    verticalArrangement = Arrangement.spacedBy(16.dp),
                    modifier = Modifier.alpha(if(balance.isEmpty()) 1.0f else 0.0f)
                ){
                    Text(
                        text = instructions,
                        textAlign = TextAlign.Center,
                        modifier = Modifier.fillMaxWidth()
                    )

                    if(showNfcSettingsButton && balance.isEmpty()){
                        val context = LocalContext.current
                        Button(
                            onClick = { context.startActivity(Intent(Settings.ACTION_NFC_SETTINGS)) }
                        ){
                            Text("Open NFC Settings")
                        }
                    }
                }
            }
        }

        val preferenceManager = PreferenceManager.getDefaultSharedPreferences(LocalContext.current)
        if(preferenceManager.getBoolean("debugging_enabled", false) || LocalInspectionMode.current){
            Column {
                Text(
                    text = debugText.trimEnd(),
                    fontFamily = FontFamily.Monospace,
                    fontSize = 12.sp,
                    lineHeight = 16.sp,
                    modifier = Modifier.padding(16.dp)
                )
            }
        }
    }
}

@Preview(showSystemUi = false)
@Composable
fun HomePreview(){
    MFCBalanceTheme {
        Home(
            instructions = "NFC is disabled on your device",
            showNfcSettingsButton = true,
            balance = "",
            ageString = "",
            debugText = ""
        )
    }
}

@Preview(showSystemUi = false)
@Composable
fun HomePreviewScanned(){
    MFCBalanceTheme {
        Home(
            instructions = "",
            showNfcSettingsButton = false,
            balance = "24.88 €",
            ageString = "a few seconds ago",
            debugText = "Debug Text\n--> Lorem\n--> Ipsum\n"
        )
    }
}
