package de.drmaxnix.mfcbalance.util

import java.util.Locale

object BalanceFormatter {
    fun numberFormat(
        number: UInt,
        divisor: Int,
        currencySymbol: String
    ): String {
        // BUILD FORMAT STRING //
        DebugLog.addLine(level = 0, line = "Building format string")

        // number with optional decimal point
        var formatString = when(divisor){
            1 -> "%.0f"
            10 -> "%.1f"
            100 -> "%.2f"
            1000 -> "%.3f"
            else -> ""
        }

        // add optional currency symbol
        formatString = when(currencySymbol){
            "$", "£", "¥" -> "$currencySymbol $formatString"
            "€" -> "$formatString $currencySymbol"
            "none" -> formatString
            else -> ""
        }
        DebugLog.addLine(level = 1, line = "Format string: '$formatString'")


        // APPLY DIVISOR //
        DebugLog.addLine(level = 0, line = "Applying divisor")
        val numberDouble: Double = number.toDouble() / divisor.toDouble()
        DebugLog.addLine(level = 1, line = "Number double: $numberDouble")


        // APPLY FORMATTING //
        // use format string
        DebugLog.addLine(level = 0, line = "Applying formatting")
        val numberString = String.format(Locale.ROOT, formatString, numberDouble)
        DebugLog.addLine(level = 1, line = "Number string: '$numberString'")

        // return
        return numberString
    }
}
