package de.drmaxnix.mfcbalance.util

import org.junit.Test
import org.junit.Assert.*

class BalanceFormatterTest {
    @Test
    fun basicTest(){
        assertEquals("$ 2.46", BalanceFormatter.numberFormat(number = 246u, divisor = 100, currencySymbol = "$"))
        assertEquals("3.00 €", BalanceFormatter.numberFormat(number = 300u, divisor = 100, currencySymbol = "€"))
        assertEquals("$ 0.17", BalanceFormatter.numberFormat(number = 17u, divisor = 100, currencySymbol = "$"))
        assertEquals("183.54 €", BalanceFormatter.numberFormat(number = 18354u, divisor = 100, currencySymbol = "€"))
    }

    @Test
    fun edgeCasesTest(){
        assertEquals("$ 0", BalanceFormatter.numberFormat(number = 0u, divisor = 1, currencySymbol = "$"))
        assertEquals("$ 0.0", BalanceFormatter.numberFormat(number = 0u, divisor = 10, currencySymbol = "$"))
        assertEquals("$ 0.00", BalanceFormatter.numberFormat(number = 0u, divisor = 100, currencySymbol = "$"))

        assertEquals("$ 0.1", BalanceFormatter.numberFormat(number = 1u, divisor = 10, currencySymbol = "$"))

        assertEquals("$ 0.999", BalanceFormatter.numberFormat(number = 999u, divisor = 1000, currencySymbol = "$"))
        assertEquals("$ 1.00", BalanceFormatter.numberFormat(number = 100u, divisor = 100, currencySymbol = "$"))

        assertEquals("$ 4294967.295", BalanceFormatter.numberFormat(number = UInt.MAX_VALUE, divisor = 1000, currencySymbol = "$"))
        assertEquals("$ 42949672.95", BalanceFormatter.numberFormat(number = UInt.MAX_VALUE, divisor = 100, currencySymbol = "$"))
        assertEquals("$ 429496729.5", BalanceFormatter.numberFormat(number = UInt.MAX_VALUE, divisor = 10, currencySymbol = "$"))
        assertEquals("$ 4294967295", BalanceFormatter.numberFormat(number = UInt.MAX_VALUE, divisor = 1, currencySymbol = "$"))
    }

    @Test
    fun divisorTest(){
        assertEquals("$ 42387", BalanceFormatter.numberFormat(number = 42387u, divisor = 1, currencySymbol = "$"))
        assertEquals("$ 4238.7", BalanceFormatter.numberFormat(number = 42387u, divisor = 10, currencySymbol = "$"))
        assertEquals("$ 423.87", BalanceFormatter.numberFormat(number = 42387u, divisor = 100, currencySymbol = "$"))
        assertEquals("$ 42.387", BalanceFormatter.numberFormat(number = 42387u, divisor = 1000, currencySymbol = "$"))
    }

    @Test
    fun currencySymbolTest(){
        assertEquals("$ 12.43", BalanceFormatter.numberFormat(number = 1243u, divisor = 100, currencySymbol = "$"))
        assertEquals("12.43 €", BalanceFormatter.numberFormat(number = 1243u, divisor = 100, currencySymbol = "€"))
        assertEquals("£ 12.43", BalanceFormatter.numberFormat(number = 1243u, divisor = 100, currencySymbol = "£"))
        assertEquals("¥ 12.43", BalanceFormatter.numberFormat(number = 1243u, divisor = 100, currencySymbol = "¥"))
        assertEquals("12.43", BalanceFormatter.numberFormat(number = 1243u, divisor = 100, currencySymbol = "none"))
    }
}