package de.drmaxnix.mfcbalance.util

import org.junit.Test
import org.junit.Assert.*

class MfcReaderTest {
    @Test
    fun hexStringToByteArrayTest(){
        assertTrue(byteArrayOf(0xab.toByte()) contentEquals MfcReader.hexStringToByteArray("ab"))
        assertTrue(byteArrayOf(0xab.toByte(), 0x8a.toByte()) contentEquals MfcReader.hexStringToByteArray("ab8a"))
        assertTrue(byteArrayOf(0xab.toByte(), 0x8a.toByte(), 0x15.toByte()) contentEquals MfcReader.hexStringToByteArray("ab8a15"))
        assertTrue(byteArrayOf(0xab.toByte(), 0x8a.toByte(), 0x15.toByte(), 0x96.toByte()) contentEquals MfcReader.hexStringToByteArray("ab8a1596"))

        assertTrue(byteArrayOf(0x00.toByte(), 0x00.toByte(), 0x00.toByte(), 0x00.toByte()) contentEquals MfcReader.hexStringToByteArray("00000000"))
        assertTrue(byteArrayOf(0xff.toByte(), 0xff.toByte(), 0xff.toByte(), 0xff.toByte()) contentEquals MfcReader.hexStringToByteArray("ffffffff"))

        assertTrue(byteArrayOf(0x10.toByte(), 0x00.toByte(), 0x00.toByte(), 0x00.toByte()) contentEquals MfcReader.hexStringToByteArray("10000000"))
        assertTrue(byteArrayOf(0x01.toByte(), 0x00.toByte(), 0x00.toByte(), 0x00.toByte()) contentEquals MfcReader.hexStringToByteArray("01000000"))
        assertTrue(byteArrayOf(0x00.toByte(), 0x10.toByte(), 0x00.toByte(), 0x00.toByte()) contentEquals MfcReader.hexStringToByteArray("00100000"))
        assertTrue(byteArrayOf(0x00.toByte(), 0x01.toByte(), 0x00.toByte(), 0x00.toByte()) contentEquals MfcReader.hexStringToByteArray("00010000"))
        assertTrue(byteArrayOf(0x00.toByte(), 0x00.toByte(), 0x10.toByte(), 0x00.toByte()) contentEquals MfcReader.hexStringToByteArray("00001000"))
        assertTrue(byteArrayOf(0x00.toByte(), 0x00.toByte(), 0x01.toByte(), 0x00.toByte()) contentEquals MfcReader.hexStringToByteArray("00000100"))
        assertTrue(byteArrayOf(0x00.toByte(), 0x00.toByte(), 0x00.toByte(), 0x10.toByte()) contentEquals MfcReader.hexStringToByteArray("00000010"))
        assertTrue(byteArrayOf(0x00.toByte(), 0x00.toByte(), 0x00.toByte(), 0x01.toByte()) contentEquals MfcReader.hexStringToByteArray("00000001"))

        assertTrue(byteArrayOf(0x00.toByte(), 0xff.toByte(), 0x00.toByte(), 0xff.toByte()) contentEquals MfcReader.hexStringToByteArray("00ff00ff"))
        assertTrue(byteArrayOf(0x01.toByte(), 0x67.toByte(), 0xab.toByte(), 0xef.toByte()) contentEquals MfcReader.hexStringToByteArray("0167abef"))
        assertTrue(byteArrayOf(0b01010101.toByte(), 0b10101010.toByte(), 0b11001100.toByte(), 0b01100110.toByte())
                contentEquals MfcReader.hexStringToByteArray("55AACC66"))
        assertTrue(byteArrayOf(0b11110000.toByte(), 0b00001111.toByte(), 0b10000000.toByte(), 0b00000001.toByte())
                contentEquals MfcReader.hexStringToByteArray("F00F8001"))
    }

    @Test
    fun byteArrayToHexStringTest(){
        assertEquals("ab", MfcReader.byteArrayToHexString(byteArrayOf(0xab.toByte())))
        assertEquals("ab8a", MfcReader.byteArrayToHexString(byteArrayOf(0xab.toByte(), 0x8a.toByte())))
        assertEquals("ab8a15", MfcReader.byteArrayToHexString(byteArrayOf(0xab.toByte(), 0x8a.toByte(), 0x15.toByte())))
        assertEquals("ab8a1596", MfcReader.byteArrayToHexString(byteArrayOf(0xab.toByte(), 0x8a.toByte(), 0x15.toByte(), 0x96.toByte())))

        assertEquals("00000000", MfcReader.byteArrayToHexString(byteArrayOf(0x00.toByte(), 0x00.toByte(), 0x00.toByte(), 0x00.toByte())))
        assertEquals("ffffffff", MfcReader.byteArrayToHexString(byteArrayOf(0xff.toByte(), 0xff.toByte(), 0xff.toByte(), 0xff.toByte())))

        assertEquals("10000000", MfcReader.byteArrayToHexString(byteArrayOf(0x10.toByte(), 0x00.toByte(), 0x00.toByte(), 0x00.toByte())))
        assertEquals("01000000", MfcReader.byteArrayToHexString(byteArrayOf(0x01.toByte(), 0x00.toByte(), 0x00.toByte(), 0x00.toByte())))
        assertEquals("00100000", MfcReader.byteArrayToHexString(byteArrayOf(0x00.toByte(), 0x10.toByte(), 0x00.toByte(), 0x00.toByte())))
        assertEquals("00010000", MfcReader.byteArrayToHexString(byteArrayOf(0x00.toByte(), 0x01.toByte(), 0x00.toByte(), 0x00.toByte())))
        assertEquals("00001000", MfcReader.byteArrayToHexString(byteArrayOf(0x00.toByte(), 0x00.toByte(), 0x10.toByte(), 0x00.toByte())))
        assertEquals("00000100", MfcReader.byteArrayToHexString(byteArrayOf(0x00.toByte(), 0x00.toByte(), 0x01.toByte(), 0x00.toByte())))
        assertEquals("00000010", MfcReader.byteArrayToHexString(byteArrayOf(0x00.toByte(), 0x00.toByte(), 0x00.toByte(), 0x10.toByte())))
        assertEquals("00000001", MfcReader.byteArrayToHexString(byteArrayOf(0x00.toByte(), 0x00.toByte(), 0x00.toByte(), 0x01.toByte())))

        assertEquals("00ff00ff", MfcReader.byteArrayToHexString(byteArrayOf(0x00.toByte(), 0xff.toByte(), 0x00.toByte(), 0xff.toByte())))
        assertEquals("0167abef", MfcReader.byteArrayToHexString(byteArrayOf(0x01.toByte(), 0x67.toByte(), 0xab.toByte(), 0xef.toByte())))
        assertEquals("55aacc66", MfcReader.byteArrayToHexString(byteArrayOf(0b01010101.toByte(), 0b10101010.toByte(), 0b11001100.toByte(), 0b01100110.toByte())))
        assertEquals("f00f8001", MfcReader.byteArrayToHexString(byteArrayOf(0b11110000.toByte(), 0b00001111.toByte(), 0b10000000.toByte(), 0b00000001.toByte())))
    }

    @Test
    fun numberExtractTest(){
        val balance0017at3to4 = MfcReader.hexStringToByteArray("00000000110000000000000000000000")
        val balance18354at14to15 = MfcReader.hexStringToByteArray("000000000000000000000000000047B2")
        val balance14232864at0to2 = MfcReader.hexStringToByteArray("D92D2000000000000000000000000000")
        val balance965412385at7to10 = MfcReader.hexStringToByteArray("00000000000000398B06210000000000")

        assertEquals(17u, MfcReader.numberExtract(
            blockData = balance0017at3to4,
            byteOffset = 4,
            numberSize = 8,
            byteorder = "be"
        ))
        assertEquals(17u, MfcReader.numberExtract(
            blockData = balance0017at3to4,
            byteOffset = 4,
            numberSize = 8,
            byteorder = "le"
        ))

        assertEquals(17u, MfcReader.numberExtract(
            blockData = balance0017at3to4,
            byteOffset = 3,
            numberSize = 16,
            byteorder = "be"
        ))
        assertEquals(4352u, MfcReader.numberExtract(
            blockData = balance0017at3to4,
            byteOffset = 3,
            numberSize = 16,
            byteorder = "le"
        ))

        assertEquals(18354u, MfcReader.numberExtract(
            blockData = balance18354at14to15,
            byteOffset = 14,
            numberSize = 16,
            byteorder = "be"
        ))
        assertEquals(45639u, MfcReader.numberExtract(
            blockData = balance18354at14to15,
            byteOffset = 14,
            numberSize = 16,
            byteorder = "le"
        ))

        assertEquals(14232864u, MfcReader.numberExtract(
            blockData = balance14232864at0to2,
            byteOffset = 0,
            numberSize = 24,
            byteorder = "be"
        ))
        assertEquals(2108889u, MfcReader.numberExtract(
            blockData = balance14232864at0to2,
            byteOffset = 0,
            numberSize = 24,
            byteorder = "le"
        ))

        assertEquals(965412385u, MfcReader.numberExtract(
            blockData = balance965412385at7to10,
            byteOffset = 7,
            numberSize = 32,
            byteorder = "be"
        ))
        assertEquals(554076985u, MfcReader.numberExtract(
            blockData = balance965412385at7to10,
            byteOffset = 7,
            numberSize = 32,
            byteorder = "le"
        ))
    }
}